package org.shadoware.eggskeeper;

import org.shadoware.eggskeeper.engine.Animator;
import org.shadoware.eggskeeper.engine.LiveSceneElement;
import org.shadoware.eggskeeper.engine.Textures;
import org.shadoware.eggskeeper.engine.Updatable;

import android.animation.FloatEvaluator;
import android.content.Context;


public class Dragon extends LiveSceneElement implements Fighter, Updatable {
	
	private final String ANIM_FLY_LEFT 	= "fly-left";
	private final int[] SEQ_LEFT 			= { 2, 		3 };
	private final int[] TIME_LEFT  		= { 300, 	300 };
	
	private final String ANIM_FLY_RIGHT 	= "fly-right";
	private final int[] SEQ_RIGHT 		= { 0, 		1,		0,		1 };
	private final int[] TIME_RIGHT 		= { 300, 	300,	700,	200 };
	
	
	private final Egg egg;
	private final Fireball fireball;
	
	// animation
	private final Animator animator;
	private float lastPositionX;
	private String activeAnimation;
	
	
	public Dragon(Context context) {
		
		super(2, "textured");
		init(context);
		egg	= new Egg(context);
		fireball = new Fireball(context);
		
		animator = new Animator();
		animator.addAnimation( ANIM_FLY_LEFT, 	SEQ_LEFT, 	TIME_LEFT  );
		animator.addAnimation( ANIM_FLY_RIGHT, 	SEQ_RIGHT, 	TIME_RIGHT ) ;
		activeAnimation = ANIM_FLY_RIGHT;
	}
	
	
	/**
	 * Init the properties of the element
	 */
	private void init(Context context) {
		
		int mTexture = Textures.getInstance().addTexture(context, "dragon-anim.png");
    	setSize(0.6f);
    	setPosition(0.0f, 0.6f, 0.0f);
    	getShape().getSize().setX(0.5f);
    	getShape().getSize().setY(0.3f);
    	getBody().getOscAmplitude().setX(0.5f);
    	getBody().getOscFrequency().setX((float) (2*Math.PI*0.25f));
    	setTexture(mTexture);
	}
	
	
	public Egg getEgg() {
		return egg;
	}
	
	
	public Fireball getFireball() {
		return fireball;
	}
	
	
	public void update() {
		
		attack(true);
		updateAnimation();
	}


	/**
	 * The dragon drop its egg when hurted
	 */
	public void getHurted() {
		
		egg.drop( getPosition() );
	}


	public void move(float speed) {
		// TODO Auto-generated method stub
		
	}

	public void attack(boolean attacking) {
		
		if ( attacking && !fireball.isActivated() ) {
			fireball.activate(getPosition());
		}
		
	}


	public boolean isAttacking() {
		
		return false;
	}
	
	
	private void updateAnimation() {
		
		if (getPosition().getX() > lastPositionX ) {
			
			activeAnimation = ANIM_FLY_RIGHT;
			
		} else {
			
			activeAnimation = ANIM_FLY_LEFT;
		}
		
		lastPositionX = getPosition().getX();
		
		animator.update(activeAnimation);
		activeFrame = animator.getFrame(activeAnimation);
	}
	

}
