package org.shadoware.eggskeeper;

import org.shadoware.eggskeeper.engine.LiveSceneElement;
import org.shadoware.eggskeeper.engine.Textures;
import org.shadoware.eggskeeper.engine.math.Tuple3f;

import android.content.Context;


public class Egg extends LiveSceneElement {
	
	private final float ROTATION_SPEED 	= 	90.0f;
	private final float GRAVITY			=  - 0.6f;
	
	
	private boolean dropped;
	
	
	public Egg(Context context) {
		
		super("textured");
		init(context);
	}
	
	
	/**
	 * Init the properties of the element
	 */
	private void init(Context context) {
		
		int mTexture = Textures.getInstance().addTexture(context, "egg.png");
    	setSize(0.1f);
    	setPosition(0.0f, 0.0f, 0.0f);
    	getShape().getSize().setX(0.1f);
    	getShape().getSize().setY(0.1f);
    	getBody().getRotationSpeed().setZ(ROTATION_SPEED);
    	setTexture(mTexture);
    	restart();
	}

	
	/** 
	 * If the egg is in the dragon or flying
	 */
	public boolean isDropped() {
		
		return dropped;
	}
	
	
	/**
	 * The egg is released
	 */
	public void drop( Tuple3f position ) {
		
		dropped = true;
		setVisible( true );
		setPosition( position.getX(), position.getY(), position.getZ() );
		getBody().clearMotion();
		getBody().getAcceleration().setY( GRAVITY );
	}
	
	
	/**
	 * Returns the egg to its origin
	 */
	public void restart() {
		
		dropped = false;
		setVisible( false );
		getBody().clearMotion();
	}
	
}
