package org.shadoware.eggskeeper;

import org.shadoware.eggskeeper.engine.Animator;
import org.shadoware.eggskeeper.engine.LiveSceneElement;
import org.shadoware.eggskeeper.engine.Textures;
import org.shadoware.eggskeeper.engine.Updatable;
import org.shadoware.eggskeeper.engine.math.Tuple3f;

import android.content.Context;


public class Fireball extends LiveSceneElement implements Updatable {
	
	private final long  LIFETIME 	= 3000;		// 2 secs, in milliseconds
	private final float SPEED 	= -0.7f;
	
	private final String ANIM_FIRE 	= "fire";
	private final int[] SEQ_FIRE 		= { 0, 		1,	 	2,		3  };
	private final int[] TIME_FIRE 	= { 100, 	150,	100,	50 };
	
	private boolean activated;
	private long initTime;
	private long nowTime;
	
	private final Animator animator;
	
	
	public Fireball(Context context) {
		
		super(2, "textured");
		init(context);
		
		animator = new Animator();
		animator.addAnimation( ANIM_FIRE, SEQ_FIRE, TIME_FIRE  );
	}
	
	
	/**
	 * Init the properties of the element
	 */
	private void init(Context context) {
		
		int mTexture = Textures.getInstance().addTexture(context, "fireball-anim.png");
    	setSize(0.25f);
    	setPosition(0.0f, 0.0f, 0.0f);
    	getBody().getSpeed().setY(SPEED);
    	getShape().getSize().setX(0.20f);
    	getShape().getSize().setY(0.20f);
    	
    	setTexture(mTexture);
    	end();
	}
	
	
	/**
	 * Starts the spell
	 */
	public void activate(Tuple3f position) {
		
		if ( !activated ) {
			
			initTime = System.nanoTime() / 1000000;	// to milliseconds
			activated = true;
			setVisible( true );
			getPosition().setX( position.getX() );
			getPosition().setY( position.getY() );
		}
	}
	
	
	/** 
	 * Finish the spell. It can not be controlled externally
	 */
	public void end() {
		
		activated = false;
		setVisible(false);
	}
	
	
	/**
	 * Update the spell
	 */
	public void update() {
		
		if ( activated ) {
			
			nowTime = System.nanoTime() / 1000000;	// to milliseconds
			
			// check if the spell die
			if ( nowTime > (initTime + LIFETIME) ) {
				end();
			}
			
			animator.update(ANIM_FIRE);
			activeFrame = animator.getFrame(ANIM_FIRE);
		}
	}


	public boolean isActivated() {
		return activated;
	}

}
