package org.shadoware.eggskeeper;

import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.opengles.GL10;

import org.shadoware.eggskeeper.engine.Scene;
import org.shadoware.eggskeeper.engine.TouchControl;
import org.shadoware.eggskeeper.engine.math.ColorRGBA;

import android.content.Context;


public class GameScene extends Scene {
	
	private final ColorRGBA SCORE_COLOR 	= new ColorRGBA( 0.0f, 0.4f, 1.0f, 1.0f);
	private final ColorRGBA LIFE_COLOR 	= new ColorRGBA( 0.6f, 0.0f, 1.0f, 1.0f);
	
	private final float SELECTED_ALPHA 	= 0.2f;		// element selected effect
	private final float NORMAL_ALPHA 		= 1.0f;
	
	private final float MAGE_SPEED		= 0.4f;
	
	private final float GROUND_Y			= -0.85f;
	private final float SCENE_LIMIT		=  0.5f;
	
	
	private final int EGG_POINTS		= 1;
	private final int STARTING_LIFE 	= 3;
	
	
	private Counter 	score;
	private Counter 	life;
	private Mage 		mage;
	private Dragon		dragon;
	private Touch		touch;
	private Spell		spell;
	private Owl			owl;

	
	public GameScene(Context context, int width, int height, ColorRGBA bgColor) {
		super(context, width, height, bgColor);
	}
	
	
	@Override
	public void onSurfaceCreated(GL10 gl, EGLConfig config) {
		
		super.onSurfaceCreated(gl, config);
		
		score 	= new Counter("Score: ", 0.7f, -0.2f, 0.65f, SCORE_COLOR, 0 );
		life 	= new Counter("Life: " , 0.7f,  0.65f, 0.65f, LIFE_COLOR, STARTING_LIFE );
		mage	= new Mage(context);
		dragon	= new Dragon(context);
		touch	= new Touch(context, getControllerPad());
		spell	= new Spell(context);
		owl		= new Owl(context);
		
		
		getElements().add( new Background(context) );
		getElements().add( owl );
		getElements().add( score );
		getElements().add( life );
		getElements().add( mage );
		getElements().add( dragon );
		getElements().add( dragon.getEgg() );
		getElements().add( dragon.getFireball() );
		getElements().add( touch );
		getElements().add( spell );
    	
	}
	
	
	/**
     * Main iteration loops
     */
	@Override
    public void onDrawFrame(GL10 gl) {
		
		controlActions();
		checkCollisions();
		checkLife();
		
		super.onDrawFrame(gl);
	}
	
	
	/**
	 * Read the controller and do the actions
	 */
	private void controlActions() {
		
		if (getControllerPad().isPressed()) {
			
			// left
			if ( getControllerPad().getKeys()[TouchControl.KEY_LEFT] ) {
				
				if (mage.getPosition().getX() > -SCENE_LIMIT) {
					mage.move( -MAGE_SPEED );
				} else {
					mage.stop();
				}
				
			// right
			} else if ( getControllerPad().getKeys()[TouchControl.KEY_RIGHT] ) {
				
				if (mage.getPosition().getX() < SCENE_LIMIT) {
					mage.move( MAGE_SPEED );
				} else {
					mage.stop();
				}
				
			// up and down
			} else {
				
				mage.stop();
				
				// up
				if (getControllerPad().getKeys()[TouchControl.KEY_UP]) {
					mage.attack(true);
					spell.activate(mage.getPosition());
				}
			}
			
		// released
		} else {
			mage.move(0);
		}
	}
    
	
	/**
	 * Checks all the defined collisions
	 */
	private void checkCollisions() {
		
		checkSpellDragonCollision();
		checkMageEggCollision();
		checkFireballMageCollision();
	}
	
	
	/**
	 * Checks if the spell impacts in the dragon
	 */
	private boolean checkSpellDragonCollision() {
		
		// spell impact in the dragon
		if (  spell.isActivated() &&
			 !dragon.getEgg().isDropped() && 
			  dragon.getShape().isIntersecting(spell.getShape()) ) {
			
			dragon.setAlpha(SELECTED_ALPHA);
			dragon.getHurted();
			return true;
			
		// the dragon is not affected by spells
		} else {
			
			dragon.setAlpha(NORMAL_ALPHA);
			return false;
		}
	}
	
	
	/**
	 * Checks if the mage catch the egg
	 */
	private boolean checkMageEggCollision() {
		
		// egg catched
		if ( dragon.getEgg().isDropped() &&
			 dragon.getEgg().getShape().isIntersecting(mage.getShape()) ) {
			
			dragon.getEgg().restart();
			score.addPoints( EGG_POINTS );
			return true;
			
		// egg crashed
		} else if ( dragon.getEgg().getPosition().getY() <  GROUND_Y ) {
			
			dragon.getEgg().restart();
			return false;
		}
		
		return false;
	}
	
	
	/**
	 * Checks if the fireball impacts in the mage
	 */
	private boolean checkFireballMageCollision() {
		
		if ( dragon.getFireball().isActivated() &&
			 dragon.getFireball().getShape().isIntersecting(mage.getShape()) ) {
			
			mage.getHurted();
			dragon.getFireball().end();
			life.addPoints( -1 );
			return true;
		}
		
		return false;
			
	}
	
	
	private void checkLife() {
		
		if (life.getPoints() <= 0) {
			System.exit(0);
		}
	}
	
}
