package org.shadoware.eggskeeper;

import org.shadoware.eggskeeper.engine.Animator;
import org.shadoware.eggskeeper.engine.LiveSceneElement;
import org.shadoware.eggskeeper.engine.Textures;
import org.shadoware.eggskeeper.engine.Updatable;

import android.content.Context;


public class Mage extends LiveSceneElement implements Fighter, Updatable {
	
	private final String ANIM_WALK_LEFT 	= "walk-left";
	private final int[] SEQ_WALK_LEFT 	= { 0, 		1 	};
	private final int[] TIME_WALK_LEFT  	= { 200, 	200 };
	
	private final String ANIM_WALK_RIGHT 	= "walk-right";
	private final int[] SEQ_WALK_RIGHT 	= { 2, 		3,	};
	private final int[] TIME_WALK_RIGHT 	= { 200, 	200 };
	
	private final String ANIM_STAND_LEFT 	= "stand-left";
	private final int[] SEQ_STAND_LEFT 	= { 0 };
	private final int[] TIME_STAND_LEFT 	= { 1000};

	private final String ANIM_STAND_RIGHT 	= "stand-right";
	private final int[] SEQ_STAND_RIGHT 	= { 2 };
	private final int[] TIME_STAND_RIGHT 	= { 1000};
	
	private boolean attacking;
	
	private final Animator animator;
	private String activeAnimation;
	private float lastSpeed;
	
	
	public Mage(Context context) {
		
		super(2, "textured");
		init(context);
		
		animator = new Animator();
		animator.addAnimation( ANIM_WALK_LEFT, 	SEQ_WALK_LEFT, 	TIME_WALK_LEFT  );
		animator.addAnimation( ANIM_WALK_RIGHT, SEQ_WALK_RIGHT, TIME_WALK_RIGHT );
		animator.addAnimation( ANIM_STAND_LEFT, SEQ_STAND_LEFT, TIME_STAND_LEFT  );
		animator.addAnimation( ANIM_STAND_RIGHT,SEQ_STAND_RIGHT,TIME_STAND_RIGHT );
		activeAnimation = ANIM_WALK_RIGHT;
	}
	
	
	/**
	 * Init the properties of the element
	 */
	private void init(Context context) {
		
		int mTexture = Textures.getInstance().addTexture(context, "mage-anim.png");
    	setSize(0.5f);
    	setPosition(0.0f, -0.70f, 0.0f);
    	setTexture(mTexture);
    	getShape().getSize().setX(0.20f);
    	getShape().getSize().setY(0.3f);
	}
	

	public boolean isAttacking() {
		
		return attacking;
	}
	
	
	public void attack(boolean attacking) {
		
		this.attacking = attacking;
	}
	
	

	public void getHurted() {
		// TODO Auto-generated method stub
		
	}


	public void move(float speed) {
		
		this.getBody().getSpeed().setX(speed);
	}

	
	public void stop() {
		move(0.0f);
	}
	
	
	public void update() {
		
		updateAnimation();
	}
	

	private void updateAnimation() {
		
		if (getBody().getSpeed().getX() > 0 ) {
			
			activeAnimation = ANIM_WALK_RIGHT;
			lastSpeed = getBody().getSpeed().getX();
			
		} else if (getBody().getSpeed().getX() < 0 ) {
			
			activeAnimation = ANIM_WALK_LEFT;
			lastSpeed = getBody().getSpeed().getX();
			
		} else {
			
			activeAnimation = (lastSpeed > 0) ? ANIM_STAND_RIGHT : ANIM_STAND_LEFT;
		}
		
		animator.update(activeAnimation);
		activeFrame = animator.getFrame(activeAnimation);
	}
	
}
