package org.shadoware.eggskeeper;

import org.shadoware.eggskeeper.engine.Animator;
import org.shadoware.eggskeeper.engine.LiveSceneElement;
import org.shadoware.eggskeeper.engine.Textures;
import org.shadoware.eggskeeper.engine.Updatable;
import org.shadoware.eggskeeper.engine.math.Tuple3f;

import android.content.Context;


public class Spell extends LiveSceneElement implements Updatable {
	
	private final long  LIFETIME 	= 2000;		// 2 secs, in milliseconds
	private final float SPEED 	= 1.2f;
	
	private final String ANIM_SPELL 	= "spell";
	private final int[] SEQ_SPELL 	= { 0, 		1,	 	2,		3  };
	private final int[] TIME_SPELL 	= { 100, 	100,	100,	100 };
	
	private boolean activated;
	private long initTime;
	private long nowTime;
	
	private final Animator animator;
	
	
	public Spell(Context context) {
		
		super(2, "textured");
		init(context);
		
		animator = new Animator();
		animator.addAnimation( ANIM_SPELL, SEQ_SPELL, TIME_SPELL  );
	}
	
	
	/**
	 * Init the properties of the element
	 */
	private void init(Context context) {
		
		int mTexture = Textures.getInstance().addTexture(context, "spell-anim.png");
    	setSize(0.2f);
    	setPosition(0.0f, 0.0f, 0.0f);
    	getBody().getSpeed().setY(SPEED);
    	getShape().getSize().setX(0.15f);
    	getShape().getSize().setY(0.15f);
    	//getBody().getOscAmplitude().setX(0.004f);
    	//getBody().getOscSpeed().setX(30.0f);
    	setTexture(mTexture);
    	end();
	}
	
	
	/**
	 * Starts the spell
	 */
	public void activate(Tuple3f position) {
		
		if ( !activated ) {
			
			initTime = System.nanoTime() / 1000000;
			activated = true;
			setVisible( true );
			getPosition().setX( position.getX() );
			getPosition().setY( position.getY() );
		}
	}
	
	
	/** 
	 * Finish the spell. It can not be controlled externally
	 */
	private void end() {
		
		activated = false;
		setVisible(false);
	}
	
	
	/**
	 * Update the spell
	 */
	public void update() {
		
		if ( activated ) {
			
			nowTime = System.nanoTime() / 1000000;
			
			// check if the spell die
			if ( nowTime > (initTime + LIFETIME) ) {
				end();
			}
			
			animator.update(ANIM_SPELL);
			activeFrame = animator.getFrame(ANIM_SPELL);
		}
	}


	public boolean isActivated() {
		return activated;
	}

}
