package org.shadoware.eggskeeper.engine;

import org.shadoware.eggskeeper.engine.math.Tuple3f;

import android.opengl.Matrix;


/**
 * Manages the view of the scene
 * 
 * @author David Henar
 *
 */
public class Camera {
	
	public static final Tuple3f Y_UP 		= new Tuple3f(  0.0f,  1.0f,  0.0f );
	public static final Tuple3f ORIGIN 	= new Tuple3f(  0.0f,  0.0f,  0.0f );
	
	
	// Position the eye behind the origin.
	private final Tuple3f eye;

	// We are looking toward the distance
	private final Tuple3f lookAt;

	// Set our up vector. This is where our head would be pointing were we holding the camera.
	private final Tuple3f up;
	
	private final HUD hud;
	
	
	/**
	 * Constructor
	 */
	public Camera() {
		eye		= new Tuple3f(  0.0f,  0.0f,  1.0f );
		lookAt	= new Tuple3f( ORIGIN );
		up		= new Tuple3f( Y_UP );
		hud		= new HUD(this);
	}
	
	
	/**
	 * Update the view matrix and the hud
	 * 
	 * @param mViewMatrix
	 */
	public void update(float[] mViewMatrix) {
		updateView(mViewMatrix);
		hud.update();
	}
	
	/**
	 * Recalculate an external view matrix
	 */
	private void updateView(float[] mViewMatrix) {
		Matrix.setLookAtM (
				mViewMatrix, 0, 
				eye.getX(), 	eye.getY(), 	eye.getZ(), 
				lookAt.getX(), 	lookAt.getY(), 	lookAt.getZ(), 
				up.getX(), 		up.getY(), 		up.getZ()
		);
	}


	public Tuple3f getEye() {
		return eye;
	}


	public Tuple3f getLookAt() {
		return lookAt;
	}


	public Tuple3f getUp() {
		return up;
	}


	public HUD getHud() {
		return hud;
	}
	
}
