package org.shadoware.eggskeeper.engine;

import org.shadoware.eggskeeper.engine.math.Tuple3f;


/**
 * Camera Y-UP view setup for 2D.
 * 
 * @author David Henar
 *
 */
public class Camera2D extends Camera {
	
	/**
	 * Constructor
	 * 
	 * @param height - initial height of the camera eye in Z axis.
	 */
	public Camera2D(float height) {
		super();
		super.getUp().set(Y_UP);
		this.setHeight2D(height);
	}
	
	
	/**
	 * Do not allow to modify this vector directly. Use setHeight2D method instead.
	 */
	@Override
	public Tuple3f getUp() {
		return null;
	}
	
	
	/**
	 * Do not allow to modify this vector directly. Use setPosition2D method instead.
	 */
	@Override
	public Tuple3f getLookAt() {
		return null;
	}
	
	
	/**
	 * Set the height of the camera. 
	 * @param height - z axis
	 */
	public void setHeight2D(float height) {
		super.getEye().setZ(height);
	}
	
	
	/**
	 * Set the position of the camera, supposing Y_UP camera
	 * 
	 * @param x
	 * @param y
	 */
	public void setPosition2D(float x, float y) {
		this.setEyePosition2D(x, y);
		this.setlookAtPosition2D(x, y);
	}

	
	/**
	 * Controlled only from setPosition to sync with lookAt
	 * 
	 * @param x
	 * @param y
	 */
	private void setEyePosition2D(float x, float y) {
		super.getEye().setX(x);
		super.getEye().setY(y);
	}
	
	
	/**
	 * Controlled only from setPosition to sync with setEye
	 * 
	 * @param x
	 * @param y
	 */
	private void setlookAtPosition2D(float x, float y) {
		super.getLookAt().setX(x);
		super.getLookAt().setY(y);
	}
	
}
