package org.shadoware.eggskeeper.engine;

import android.app.Activity;
import android.content.Context;
import android.opengl.GLSurfaceView;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.Window;
import android.view.WindowManager;


/**
 * Links the renderer with android applications
 * 
 * @author David Henar
 */
public class SceneView extends GLSurfaceView {
	
	private final byte GL_VERSION = 2; 				// OpenGL ES 2.0 context
	
	private final Scene scene;
    
	
    public SceneView(Context context, AttributeSet attrs, Scene scene) {
    	
		super(context, attrs);
		setEGLContextClientVersion(GL_VERSION);		
		this.scene = scene;
		setRenderer(scene);
	}
	
	
	/**
	 * Reports input data from the touch screen like touch position changed.
	 * The rotation is due when we make circles around the center of the screen.
	 * 
	 * @param e - input event
	 * @return - true indicates the event was received.
	 */
	@Override
	public boolean onTouchEvent(MotionEvent e) {
		
		switch (e.getAction()) {
		
		case MotionEvent.ACTION_DOWN:
			scene.getControllerPad().setTouchCenter(
				e.getX()/getWidth(), 
				e.getY()/getHeight()
			);
			scene.getControllerPad().setTouchAxis(e.getX(), e.getY());
			scene.getControllerPad().resetAngle();
			scene.getControllerPad().updateKeysPressed(e.getX(), e.getY());
			scene.getControllerPad().setPressed(true);
			
			break;
		
		case MotionEvent.ACTION_MOVE:
			
			scene.getControllerPad().updateKeysMove (
					e.getX(), 
					e.getY());
			/*
			scene.getControllerPad().updateAngle(
				e.getX(), 
				e.getY()
			);
			*/
			scene.getControllerPad().updateDiscreteAngle();
			break;
		
		case MotionEvent.ACTION_UP:
			scene.getControllerPad().resetKeys();
			scene.getControllerPad().setPressed(false);
			break;
		}
		
		return true;
	}
	
	
	/**
     * Set the window in full screen mode
     */
    public void setFullScreen(Activity context, boolean fullScreen) {
    	
    	if (fullScreen) {
    		// requesting to turn the title OFF
            context.requestWindowFeature(Window.FEATURE_NO_TITLE);
        	
        	// making it full screen
            context.getWindow().setFlags(
        		WindowManager.LayoutParams.FLAG_FULLSCREEN,
        		WindowManager.LayoutParams.FLAG_FULLSCREEN
            );
    	}
    }

}
