package org.shadoware.eggskeeper.engine;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.opengl.GLES20;
import android.opengl.GLUtils;


public class TextElement extends SceneElement {
	
	private int textSize = 32;
	private String text = "";
	
	public TextElement() {
		super("textured");
		setText("");
	}
	

	public void setText(String text) {
		
		if (this.text.equals(text)) return;
		
		this.text = text;

		//Generate one texture pointer...
		final int[] textureHandle = new int[1];
	    GLES20.glGenTextures(1, textureHandle, 0);
	 
	    if (textureHandle[0] != 0) {
	    	
	    	// Create an empty, mutable bitmap
			Bitmap bitmap = Bitmap.createBitmap(256, 256, Bitmap.Config.ARGB_4444);
			// get a canvas to paint over the bitmap
			Canvas canvas = new Canvas(bitmap);
			bitmap.eraseColor(0);

			// Draw the text
			Paint textPaint = new Paint();
			textPaint.setTextSize(textSize);
			textPaint.setAntiAlias(true);
			textPaint.setARGB(0xff, 0xff, 0xff, 0xff);
			
			// draw the text centered
			canvas.drawText(text, 0, textSize, textPaint);
	   
			// Bind to the texture in OpenGL
	        GLES20.glBindTexture(GLES20.GL_TEXTURE_2D, textureHandle[0]);
	 
	        // Set filtering
	        GLES20.glTexParameteri(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_MIN_FILTER, GLES20.GL_NEAREST);
	        GLES20.glTexParameteri(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_MAG_FILTER, GLES20.GL_NEAREST);
	 
	        // Load the bitmap into the bound texture.
	        GLUtils.texImage2D(GLES20.GL_TEXTURE_2D, 0, bitmap, 0);
	
			//Clean up
			bitmap.recycle();
			
			this.setTexture(textureHandle[0]);
		}
	}
	
}
