package org.shadoware.eggskeeper.engine;

import java.util.HashMap;
import java.util.Map;

import org.shadoware.eggskeeper.engine.util.GameResources;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.opengl.GLES20;
import android.opengl.GLUtils;


/**
 * Manages textures
 * 
 * @author David Henar
 */
public class Textures {
	
	private final static String PATH = "textures/";
	
	private final static Textures INSTANCE = new Textures();
	private final Map<String, Integer> data;
	
	
	private Textures() {
		data = new HashMap<String, Integer>();
	}
	
	
	/**
	 * Adds the texture name into the list and create into the GL context, if it was not
	 * added before.
	 */
	public int addTexture(Context context, String name) {
		if (!data.containsKey(name)) {
			return loadTexture(context, name);
		}
		else {
			return data.get(name);
		}
	}
	
	
	/**
	 * Clears the textures loaded. Use in the onCreate method to reset the old 
	 * linked indices.
	 */
	public void clearAllTextures() {
		data.clear();
	}
	
	
	/**
	 * Loads a texture resource
	 */
	private int loadTexture(Context context, String name)  {
		
	    final int[] textureHandle = new int[1];
	    GLES20.glGenTextures(1, textureHandle, 0);
	 
	    if (textureHandle[0] != 0) {
	    	
	    	// Options
	        final BitmapFactory.Options options = new BitmapFactory.Options();
	        options.inScaled = false;   // No pre-scaling
	 
	        final Bitmap bitmap = GameResources.getBitmap(PATH + name, context.getAssets());
	 
	        // Bind to the texture in OpenGL
	        GLES20.glBindTexture(GLES20.GL_TEXTURE_2D, textureHandle[0]);
	 
	        // Set filtering
	        GLES20.glTexParameteri(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_MIN_FILTER, GLES20.GL_NEAREST);
	        GLES20.glTexParameteri(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_MAG_FILTER, GLES20.GL_NEAREST);
	 
	        // Load the bitmap into the bound texture.
	        GLUtils.texImage2D(GLES20.GL_TEXTURE_2D, 0, bitmap, 0);

	        bitmap.recycle();	// Recycle the bitmap, since its data has been loaded into OpenGL.
	    }
	 
	    if (textureHandle[0] == 0) {
	        throw new RuntimeException("Error loading texture.");
	    }
	 
	    return textureHandle[0];
	}
	
	
	/**
	 * Gets the singleton instance, to access the Textures
	 */
	public static Textures getInstance() {
		return INSTANCE;
	}
	
}
