package org.shadoware.eggskeeper.engine.math;


/**
 * RGBA color
 * 
 * @author David Henar
 */
public class ColorRGBA {
	
	public static final byte R = 0;
	public static final byte G = 1;
	public static final byte B = 2;
	public static final byte A = 3;
	
	private final byte DIM = 4;
	private final float[] data;
	
	
	/**
	 * Black basic
	 */
	public ColorRGBA() {
		data = new float[DIM];
	}
	
	/**
	 * RGBA: default
	 */
	public ColorRGBA(float r, float g, float b, float a) {
		this();
		set(r,g,b,a);
	}
	
	
	/**
	 * Gets the color component
	 * 
	 * @param c: R, G, B, A
	 */
	public float get(byte c) {
		if ( (c >= 0) && (c < data.length) ) {
			return data[c];
		}
		return 0.0f;
	}
	
	
	/**
	 * Gets the color component
	 * 
	 * @param c: R, G, B, A
	 */
	public void set(byte c, float value) {
		if ( (c >= 0) && (c < data.length) ) {
			data[c] = value;
		}
	}
	
	
	/**
	 * Set the color with the given color components
	 */
	public void set(float r, float g, float b, float a) {
		data[R] = r;
		data[G] = g;
		data[B] = b;
		data[A] = a;
	}
	
	
	/**
	 * Set the color with the given color components
	 */
	public void set(float r, float g, float b) {
		data[R] = r;
		data[G] = g;
		data[B] = b;
	}
	
	
	/**
	 * Sets the alpha parameter
	 */
	public void setAlpha(float a) {
		data[A] = a;
	}
	
	
	/**
	 * Copy the color
	 */
	public void set(ColorRGBA color) {
		set(color.get(R), color.get(G), color.get(B), color.get(A));
	}
	
	
	/**
	 * Gets the array of color components
	 */
	public float[] getArrayData() {
		return data;
	}

}
