package org.shadoware.eggskeeper.engine.math;



/**
 * It represents a point in 3D
 * 
 * @author David Henar
 */
public class Tuple3f {
	
	public static final byte X = 0;
	public static final byte Y = 1;
	public static final byte Z = 2;
	
	private final byte DIM = 3;
	private final float[] data;
	
	
	public Tuple3f() {
		data = new float[DIM];
	}
	
	public Tuple3f(Tuple3f coord) {
		this();
		set(coord);
	}
	
	public Tuple3f(float x, float y, float z) {
		this();
		set(x,y,z);
	}
	
	
	/**
	 * Returns the data array
	 */
	public float[] getData() {
		return data;
	}
	
	
	public void setX(float x) {
		data[X] = x;
	}
	
	public void setY(float y) {
		data[Y] = y;
	}
	
	public void setZ(float z) {
		data[Z] = z;
	}
	
	
	/**
	 * Sets the coordinates in the given position
	 */
	public void set(float x, float y, float z) {
		setX(x);
		setY(y);
		setZ(z);
	}
	
	
	/**
	 * Copy the given point
	 */
	public void set(Tuple3f coord) {
		setX(coord.getX());
		setY(coord.getY());
		setZ(coord.getZ());
	}
	
	
	public float getX() {
		return data[X];
	}
	
	public float getY() {
		return data[Y];
	}
	
	public float getZ() {
		return data[Z];
	}
	
	
	/**
	 * Scalar multiplication
	 */
	public void scalarMul(float scalar) {
		for (int i=0; i<data.length; i++) {
			data[i] *= scalar;
		}
	}
	
	public void scalarMul(Tuple3f tuple) {
		data[X] *= tuple.getX();
		data[Y] *= tuple.getY();
		data[Z] *= tuple.getZ();
	}
	
	
	/**
	 * Add the values
	 */
	public void add(float x, float y, float z) {
		data[X] += x;
		data[Y] += y;
		data[Z] += z;
	}
	
	public void add(Tuple3f point) {
		add(point.getX(), point.getY(), point.getZ());
	}

	public void addX(float x) {
		data[X] += x;
	}
	
	public void addY(float y) {
		data[Y] += y;
	}
	
	public void addZ(float z) {
		data[Z] += z;
	}
	
	/**
	 * Reset the values of every coordinate to 0.
	 */
	public void clear() {
		for (int i=0; i<data.length; i++) {
			data[i] = 0;
		}
	}
}