package org.shadoware.eggskeeper.engine.physics;

import org.shadoware.eggskeeper.engine.math.Tuple3f;

import android.util.FloatMath;


/**
 * Fisical behavior of the bodies.
 * 
 * @author dhenar
 *
 */
public class Behavior {
	
	
	/**
	 * Calculate the new speed and position of the object according to the time increment.
	 */
	public static void updateLinealMovement(Body body, float timeInc) {
		
		Tuple3f acceleration = body.getAcceleration();
		Tuple3f speed 		 = body.getSpeed();
		Tuple3f position 	 = body.getPosition();
		
		speed.add	 ( getIncrement( acceleration, timeInc ) );	 // update speed
		position.add ( getIncrement( speed, 	   timeInc ) );	 // update acceleration
	}

	
	/**
	 * Calculate the increment of some variable like speed or space in the given time.
	 * Time is supposed to be in seconds.
	 */
	private static Tuple3f getIncrement(Tuple3f variable, float timeInc) {
		
		Tuple3f sInc = new Tuple3f(variable);
		sInc.scalarMul(timeInc);
		return sInc;
	}
	
	
	/**
	 * Calculate the new rotation
	 */
	public static void updateRotation(Body body, float timeInc) {
		
		Tuple3f r 		= body.getRotation();
		Tuple3f rSpeed 	= body.getRotationSpeed();
		
		r.add ( getIncrement( rSpeed, timeInc ) );	 // update rotation
	}
	
	
	/**
	 * Calculate the new oscillation position.
	 * 
	 * Difference beteween the oscilation of last phase and actual one.
	 */
	public static void updateOscilation(Body body, float timeInc) {
		
		Tuple3f amp 		= body.getOscAmplitude();
		Tuple3f freq 		= body.getOscFrequency();
		Tuple3f phase		= body.getOscPhase();
		Tuple3f position  	= body.getPosition();
		
		for ( int i=0; i<position.getData().length; i++) {
			position.getData()[i] -= (
				amp.getData()[i] * FloatMath.sin(phase.getData()[i]) -
				amp.getData()[i] * FloatMath.sin(phase.getData()[i] += freq.getData()[i] * timeInc)
			);
		}	
	}
	
}
