package org.shadoware.eggskeeper.engine.physics;

import org.shadoware.eggskeeper.engine.math.Tuple3f;


/**
 * It represents a physical body, and it can be used to manage motion.
 * 
 * @author David Henar
 *
 */
public class Body {
	
	// lineal
	private		    Tuple3f position;		// free to link whatever position object
	private final 	Tuple3f speed;
	private final 	Tuple3f acceleration;
	
	// oscilation
	private final Tuple3f oscAmplitude;
	private final Tuple3f oscFrequency;
	private final Tuple3f oscPhase;
	
	
	// rotation
	private 		Tuple3f rotation;		// free to link whatever rotation object
	private final 	Tuple3f rotationSpeed;
	
	
	public Body(Tuple3f position, Tuple3f rotation)
	{	
		this.position 	  	= position;
		this.rotation		= rotation;
		
		this.speed			= new Tuple3f();
		this.acceleration 	= new Tuple3f();
		
		this.oscAmplitude 	= new Tuple3f();
		this.oscFrequency 	= new Tuple3f();
		this.oscPhase 		= new Tuple3f();
		
		this.rotationSpeed	= new Tuple3f();
	}
	
	
	public Tuple3f getPosition() {
		
		return position;
	}


	public void setPosition(Tuple3f position) {
		
		this.position = position;
	}


	public Tuple3f getSpeed() {
		
		return speed;
	}
	
	public Tuple3f getAcceleration() {
		
		return acceleration;
	}
	
	
	public Tuple3f getRotation() {
		
		return rotation;
	}


	public void setRotation(Tuple3f rotation) {
		
		this.rotation = rotation;
	}
	

	public Tuple3f getRotationSpeed() {
		
		return rotationSpeed;
	}

	
	/**
	 * Setted by the user
	 */
	public Tuple3f getOscAmplitude() {
		
		return oscAmplitude;
	}
	

	/**
	 * Should be setted as 2*PI*f
	 */
	public Tuple3f getOscFrequency() {
		
		return oscFrequency;
	}


	/**
	 * Shoud be modified only by the Behaviour object
	 */
	public Tuple3f getOscPhase() {
		return oscPhase;
	}


	/**
	 * Updates all the attributes of the body according to the time increment.
	 */
	public void update(float timeInc) {
		
		Behavior.updateLinealMovement(this, timeInc);
		Behavior.updateRotation(this, timeInc);
		Behavior.updateOscilation(this, timeInc);
	}
	
	
	/**
	 * Resets the speed and acceleration
	 */
	public void clearMotion() {
		
		acceleration.clear();
		speed.clear();
	}
		
}
