package org.shadoware.eggskeeper.engine.sound;

import java.io.IOException;
import java.util.HashMap;

import org.shadoware.eggskeeper.engine.util.GameResources;

import android.content.Context;
import android.content.res.AssetManager;
import android.media.AudioManager;
import android.media.SoundPool;


public class Sounds {
	
	private static final String 	SOUND_EXTENSION = ".ogg";
	private static final String 	PATH 			= "sounds";
	private static final byte 	MAX_STREAMS		= 8;
	
	private static Sounds _instance = new Sounds();
	
	private HashMap<String, Integer> mSounds = new HashMap<String, Integer>();
	
	private  SoundPool 		mSoundPool;
	private  AudioManager  mAudioManager;
	private  Context 		mContext;
	
	
	private Sounds() {
		
	}
	
	
	public void initSounds(Context context) {
		
	    mContext 		= context;
	    mSoundPool 		= new SoundPool(MAX_STREAMS, AudioManager.STREAM_MUSIC, 0);
	    mAudioManager 	= (AudioManager)mContext.getSystemService(Context.AUDIO_SERVICE);
	    loadSounds();
	}
	
	
	/**
	 * Loads all the sounds in the assets
	 */
	private void loadSounds() {
		
		try {
			String soundName;
			String files[] = GameResources.getDirectoryFiles(PATH, mContext.getAssets());
			
			mSounds.clear();
			
			for (String file : files) {
				soundName = GameResources.getFileBaseName(file);
				if (GameResources.getFileExtension(file).equals(SOUND_EXTENSION)) {
					mSounds.put(soundName, loadSound(file, mContext.getAssets()));
				}
				soundName = null;
			}
			
		} catch (IOException e) { }
	}
	
	
	/**
	 * Load a sound into the Sound Pool
	 */
	private int loadSound(String file, AssetManager assets) throws IOException {
		
		return mSoundPool.load(assets.openFd(file), 1);
	}

	
	/**
	 * Set the volume of a sound
	 */
	public void volume(String sound, float volume) {
		
		mSoundPool.setVolume(mSounds.get(sound), volume, volume);
	}
	
	
	/**
	 * Play a sound, once or loop.
	 */
	public void play(String sound, boolean loop) {
		
		float volume;
		volume  = mAudioManager.getStreamVolume(AudioManager.STREAM_MUSIC);
		volume /= mAudioManager.getStreamMaxVolume(AudioManager.STREAM_MUSIC);
		
	    mSoundPool.play(
	    		mSounds.get(sound), 
	    		volume, 
	    		volume, 
	    		1, 
	    		loop? -1 : 0, 
	    		1f
	    );
	}
	
	
	/**
	 * Stop a sound.
	 */
	public void stop(String sound) {
		
		mSoundPool.stop(mSounds.get(sound));
	}


	/**
	 * Deallocates the resources and Instance of SoundManager.
	 */
	public void cleanup() {
		mSoundPool.release();
	    mSounds.clear();
	    mAudioManager.unloadSoundEffects();
	    _instance = null;
	}
	
	public void pauseAll() {
		mSoundPool.autoPause();
	}
	
	
	/**
	 * Gets the singleton instance
	 */
	public static synchronized Sounds getInstance() {
		
		if (_instance == null) _instance = new Sounds();
		return _instance;
	}
	
}
