package org.shadoware.eggskeeper.engine.util;


/**
 * Display the Frames Per Second
 * 
 * @author David Henar
 */
public class FPSCounter {
	
	private final long  TIME_PERIOD = 1000000000;		// 1 second (nanosec), sample count period time
	private final float NANO_TIME   = 1000000000.0f;	// nanoseconds in a second
	
	private int 	lastFps;
	private int 	fps;
	private long 	initialTime;		// record time at the begining of every period
	private long 	nowTime;
	private float	timeInc;
	
	private boolean enabled = true;

	
	/**
	 * Start/Stops the counter
	 */
	public void enable(boolean enabled) {
		this.enabled = enabled;
	}
	
	/**
	 * Should be called in every onDrawFrame loop cycle
	 */
	public void update() {
		
		if (enabled) {
			
			fps++;
			
			// get time increment in seconds, avoid the first fake result
			if (nowTime != 0) {
				timeInc = (System.nanoTime() - nowTime) / NANO_TIME;
			}
			nowTime = System.nanoTime();
			
			// check the FPS after a second
			if (nowTime > initialTime + TIME_PERIOD) {
				lastFps = fps-1;
				fps=0;
				initialTime = nowTime;
			}
		}
	}
	
	public int getFps() {
		return lastFps;
	}

	
	/**
	 * Gets the time increment since the last frame
	 */
	public float getTimeInc() {
		return timeInc;
	}
}
