package org.shadoware.eggskeeper.engine.util;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;


/**
 * Helps to get the resources used in the game
 * 
 * @author David Henar
 *
 */
public class GameResources {
	
	/**
	 * Loads a bitmap from asset directory
	 */
	public static Bitmap getBitmap(String file, AssetManager manager) {
		
	    InputStream is;
	    Bitmap bitmap = null;
	    
	    try {
	        is = manager.open(file);
	        bitmap = BitmapFactory.decodeStream(is);
	        
	    } catch (IOException e) {
	        return null;
	    }

	    return bitmap;
	}
	
	
	/**
	 * Gets the list of the all files into a directory
	 */
	public static String[] getDirectoryFiles(String dir, AssetManager manager) throws IOException {
		
		StringBuilder sb;
		
		String[] files = manager.list(dir);
		
		for (int i=0; i<files.length; i++) {
			sb = new StringBuilder();
			sb.append(dir);
			sb.append("/");
			sb.append(files[i]);
			files[i] = sb.toString();
			sb = null;
		}
		
		return files;
	}
	
	
	/**
	 * Reads a text file into string
	 */
	public static String readTextFile(String file, AssetManager manager) {
		
		InputStream is;
		InputStreamReader isReader;
		BufferedReader bufferedReader;
		
		String line;
		StringBuilder code = new StringBuilder();
		
		try {
			is = manager.open(file);
			isReader = new InputStreamReader(is);
			bufferedReader = new BufferedReader(isReader);
			
			while ((line = bufferedReader.readLine()) != null) {
	            code.append(line);
	            code.append('\n');
	        }
			   
		    is.close();
		} 
		catch (IOException e) {
			return null;
		}
		
		return code.toString();
	}
		
	
	/**
	 * Gets the name of a file without the dot, suffix, prefix and directory bar, from an absolute
	 * uri path.
	 */
	public static String getFileBaseName(String fileName) {
		
		if (fileName.contains("/")) {
			return fileName.substring(fileName.indexOf("/")+1, fileName.indexOf("."));
		} else {
			return fileName.substring(0, fileName.indexOf("."));
		}
	}
	
	
	/**
	 * Gets the name of a file without the dot, suffix, prefix and directory bar, from an absolute
	 * uri path.
	 */
	public static String getFileExtension(String fileName) {
		return fileName.substring(fileName.indexOf("."), fileName.length());
	}
	
}
